# Generated by Django 3.0.5 on 2020-05-04 12:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
        ('feeds', '0006_auto_20190901_1644'),
    ]

    operations = [
        migrations.CreateModel(
            name='ICalFeedWidget',
            fields=[
                ('dashboardwidget_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='core.DashboardWidget')),
                ('url', models.URLField(verbose_name='iCalendar URL')),
                ('base_url', models.URLField(help_text='The widget will have a link to visit a related website to see more events', verbose_name='Base URL of related calendar')),
                ('events_count', models.IntegerField(default=5, verbose_name='Number of displayed events')),
            ],
            options={
                'verbose_name': 'iCalendar Widget',
                'verbose_name_plural': 'iCalendar Widgets',
            },
            bases=('core.dashboardwidget',),
        ),
        migrations.CreateModel(
            name='RSSFeedWidget',
            fields=[
                ('dashboardwidget_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='core.DashboardWidget')),
                ('url', models.URLField(verbose_name='RSS feed source URL')),
                ('base_url', models.URLField(help_text='The widget will have a link to visit a related website to read more news', verbose_name='Base URL of related website')),
                ('text_only', models.BooleanField(default=False, help_text='Do not show an image to depict the news item', verbose_name='Text only')),
                ('rss_source', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to='feeds.Source')),
            ],
            options={
                'verbose_name': 'RSS Widget',
                'verbose_name_plural': 'RSS Widgets',
            },
            bases=('core.dashboardwidget',),
        ),
    ]
